@@ -47,7 +47,7 @@ GUI.MANOVA <- function() {
   # Create window
   window <- RGtk2::gtkWindow()
   # Add title
-  window["title"] <- "Tests for repeated measures designs"
+  window["title"] <- "Tests for multivariate data"
   # Add a frame
   frame <- RGtk2::gtkFrameNew("Specify data location and formula...")
   window$add(frame)
